package com.malk.kuaikeli.service;

import com.malk.server.common.McR;
import org.springframework.scheduling.annotation.Async;

import java.util.List;
import java.util.Map;

public interface KKLService {

    void matchSupplier(Map data);

    boolean validateApprove(Map data);

    void planApproval(Map data);

    @Async
    void updateState(String id);

    @Async
    void serviceRate(Map data);

    void adjustCost(Map data);

    void additionMaterial(Map data);

    void syncPrice();

    List<Map<String, String>> getDiffMatchingSuppliers(String oldSupplierCode,String newSupplierCode);

    @Async
    void updateSuppliers(String formInstId);

    List<Map<String, String>> getDiffMatchingSuppliers2(String projectCode,String oldSupplierCode, String newSupplierCode);

    void purchaseConfirmation(String formInstId);

}
